@@ -4,7 +4,7 @@ import sshtunnel
 import typing
 from contextlib import contextmanager
 
-from marshmallow import ValidationError
+from marshmallow import EXCLUDE
 from sqlalchemy import event
 from sqlalchemy.orm import Session
 
@@ -83,9 +83,7 @@ def session_scope(db: typing.Optional[str] = None):
 def create(session, model, schema, obj):
     """Validates the `obj` against the `schema` and
     creates a new row."""
-    data, errors = schema().load(obj)
-    if errors:
-        raise ValidationError(errors)
+    data = schema().load(obj, unknown=EXCLUDE)
 
     instance = model(**data)
     session.add(instance)
@@ -111,9 +109,7 @@ def get_or_create(session, model, schema, obj: typing.Dict) -> typing.Tuple:
     if instance:
         return instance, False
 
-    data, errors = schema().load(obj)
-    if errors:
-        raise ValidationError(errors)
+    data = schema().load(obj, unknown=EXCLUDE)
 
     instance = model(**data)
     session.add(instance)
@@ -144,9 +140,7 @@ def get_or_create_by_filter(
     if instance:
         return instance, False
 
-    data, errors = schema().load(obj)
-    if errors:
-        raise ValidationError(errors)
+    data = schema().load(obj, unknown=EXCLUDE)
 
     instance = model(**data)
     session.add(instance)
@@ -176,9 +170,7 @@ def update_or_create(
     )
 
     # Validate
-    data, errors = schema().load(obj)
-    if errors:
-        raise ValidationError(errors)
+    data = schema().load(obj, unknown=EXCLUDE)
 
     if instance:
         # Update
