@@ -7,6 +7,7 @@ from sqlalchemy import (
     ForeignKey,
     UniqueConstraint,
     Float,
+    Boolean,
 )
 
 from ...database import Base
@@ -30,6 +31,7 @@ class InterventionDataConditionModel(Base):
         Float,
         nullable=False,
     )
+    preferred = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
