@@ -13,4 +13,6 @@ class InterventionDataRawResourceSchema(Schema):
     source_id = fields.Integer(required=True)
     insight_type = fields.String(required=True)
     insight_name = fields.String()
+    score = fields.Float(allow_none=True)
+    preferred = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
