@@ -46,7 +46,7 @@ class OrangeBookPatentResourceSchema(Schema):
     submission_date = fields.DateTime(required=True, allow_none=True)
 
     @pre_load
-    def pre_load_date_fields(self, in_data):
+    def pre_load_date_fields(self, in_data, **kwargs):
         return pre_load_helper(in_data)
 
 
@@ -77,5 +77,5 @@ class OrangeBookPatentPatchSchema(Schema):
     submission_date = fields.DateTime(allow_none=True)
 
     @pre_load
-    def pre_load_date_fields(self, in_data):
+    def pre_load_date_fields(self, in_data, **kwargs):
         return pre_load_helper(in_data)
